MethodChannelWxpay class
- Inheritance
-
- Object
- PlatformInterface
- WxpayPlatform
- MethodChannelWxpay
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getJsapiOpenid(
) → Future< String?> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
init(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
payH5(
String url) → Future< void> -
override
-
payJsapi(
Map< String, dynamic> config, Function callback) → Future<void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited